@@ -39,7 +39,7 @@
 /* #define SWAP(a,b) tempr=(a);(a)=(b);(b)=tempr */
 
 #define USAGE "\
-Usage: rr [--c_dif] [--no_cdif] [--cf int] [--cl int] [--cp int] \n\
+Usage: gpiv_rr [--c_dif] [--no_cdif] [--cf int] [--cl int] [--cp int] \n\
           [-g] [--gauss][-h | --help] [--ia_size_i int] [--ia_size_f int] \n\
           [--ia_shift int] [--ischeme int] [--ifit 0/1/2/3] [--linec int int int] \n\
           [--liner int int int] [-p | --print] [--peak 1/2/3] [--p_piv] \n\
@@ -104,8 +104,7 @@ keys: \n\
 rr interrogates an image (pair) in order to obtain displacements of \n\
 particles for (Digital) Particle Image Velocimetry (PIV). \n\
 "
-
-#define RCSID "$Id: rr.c,v 3.23 2007-12-19 08:47:49 gerber Exp $"
+#define RCSID "$Id: rr.c,v 3.26 2008-09-25 13:18:48 gerber Exp $"
 
 /*
  * Global parameters and variables
@@ -162,7 +161,7 @@ command_args (int argc,
                 break;
                 
             case 'h':
-                printf ("%s\n", RCSID);
+                printf ("%s\n", argv[0]);
                 printf ("%s\n", HELP);
                 printf ("%s", USAGE);
 #ifdef DEBUG
@@ -201,7 +200,7 @@ command_args (int argc,
                  */
             case '-':
                 if (strcmp ("-help", *argv) == 0) {
-                    printf ("\n%s", RCSID);
+                    printf ("\n%s", argv[0]);
                     printf ("\n%s", HELP);
                     printf ("\n%s", USAGE);
                     exit (0);
@@ -242,18 +241,13 @@ command_args (int argc,
                     --argc;
                     argc_next = 1;
 
-                    /* 		} else if (strcmp ("cmpr", *argv) == 0) { */
-                    /* 		    cmpr = 1; */
-                    /* 		    cmpr__set = TRUE; */
-                    /* 		    --argc; */
-                    /* 		    argc_next = 1; */
-
                     /*
                      * interrogation area weighting with gauss function
                      */
                 } else if (strcmp ("-gauss", *argv) == 0) {
                     piv_par->gauss_weight_ia = TRUE;
                     piv_par->gauss_weight_ia__set = TRUE;
+
                     /*
                      * overrides Rr.int_size_f
                      */
@@ -292,7 +286,7 @@ command_args (int argc,
                         && piv_par->int_scheme != 3 
                         && piv_par->int_scheme != 4) {
                         gpiv_error ("%s: invalid value of Int_scheme (1, 2, 3 or 4)", 
-                                    RCSID);
+                                    argv[0]);
                     }
                     piv_par->int_scheme__set = TRUE;
                     --argc;
@@ -307,7 +301,7 @@ command_args (int argc,
                         piv_par->ifit != 1 && piv_par->ifit != 2
                         && piv_par->ifit != 3) {
                         gpiv_error ("%s: invalid value of Ifit (1, 2 or 3)", 
-                                    RCSID);
+                                    argv[0]);
                     }
                     piv_par->ifit__set = TRUE;
                     --argc;
@@ -329,7 +323,7 @@ command_args (int argc,
                                     " may be defined\n"
                                     " not a vertical, a point or an area of"
                                     " interest as well\n",
-                                    RCSID);
+                                    argv[0]);
                     } else {
                         piv_par->int_geo__set = TRUE;
                     }
@@ -350,7 +344,7 @@ command_args (int argc,
                                     " may be defined\n"
                                     " not an horizontal, a point or an area of"
                                     " interest as well\n",
-                                    RCSID);
+                                    argv[0]);
                     } else {
                         piv_par->int_geo__set = TRUE;
                     }
@@ -389,7 +383,7 @@ command_args (int argc,
                         gpiv_error ("%s: only a point may be defined\n"
                                     " not an horizontal, a vertical line"
                                     " or an area of interest as well\n",
-                                    RCSID);
+                                    argv[0]);
                     } else {
                         piv_par->int_geo__set = TRUE;
                     }
@@ -447,7 +441,7 @@ command_args (int argc,
                         && valid_par->residu_type != 1 
                         && valid_par->residu_type != 2) {
                         gpiv_error ("%s: invalid value of VALID.Residu_type (0, 1, or 2)", 
-                                    RCSID);
+                                    argv[0]);
                     }
                     
                     /*
@@ -463,7 +457,7 @@ command_args (int argc,
                         && valid_par->subst_type != 2
                         && valid_par->subst_type != 3) {
                         gpiv_error ("%s: invalid value of VALID.Subst_type (0, 1, 2 or 3)", 
-                                    RCSID);
+                                    argv[0]);
                     }
 
                     /*
@@ -476,13 +470,13 @@ command_args (int argc,
                     argc_next = 1;
 
                 } else {
-		    gpiv_error ("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error ("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
 
 	    default:
-		gpiv_error ("%s: unknown option: %s", RCSID, *argv);
+		gpiv_error ("%s: unknown option: %s", argv[0], *argv);
 		break;
 
 	    }
@@ -501,10 +495,10 @@ command_args (int argc,
         if (gnuplot == 1) {
             gpiv_error ("%s: an image filename for input has to be used "
                         "in combination with 'gnuplot'", 
-                        RCSID);
+                        argv[0]);
         }
     } else {
-        gpiv_error("\n%s: unknown argument: %s: %s", RCSID, *argv, USAGE);
+        gpiv_error("\n%s: unknown argument: %s: %s", argv[0], *argv, USAGE);
     }
 
 
@@ -554,6 +548,48 @@ make_fname (FILE * fp_par_out,
 }
 
 
+#ifdef ENABLE_MPI
+
+static GpivImage *
+alloc_image_struct(void)
+/*-----------------------------------------------------------------------------
+ * Allocates GpivImage structure
+ */
+{
+    GpivImage *image = g_new0 (GpivImage, 1);
+    GpivImagePar *image_par = g_new0 (GpivImagePar, 1);;
+
+
+    image->header = image_par;
+
+
+    return image;
+}
+
+
+static GpivPivPar *
+alloc_pivpar_struct(void)
+/*-----------------------------------------------------------------------------
+ * Allocates GpivPivPar structure
+ */
+{
+    GpivPivPar *piv_par = g_new0 (GpivPivPar, 1);
+    return piv_par;
+}
+
+
+static GpivValidPar *
+alloc_validpar_struct(void)
+/*-----------------------------------------------------------------------------
+ * Allocates GpivValidPar structure
+ */
+{
+    GpivValidPar *valid_par = g_new0 (GpivValidPar, 1);
+    return valid_par;
+}
+
+#endif /* ENABLE_MPI */
+
 
 int 
 main (int argc, 
@@ -575,150 +611,217 @@ main (int argc,
     GpivPivPar *piv_par = g_new0 (GpivPivPar, 1);
     GpivValidPar *valid_par = g_new0 (GpivValidPar, 1);
     
+#ifdef _OPENMP
+    int np, nprocs, num_threads;
+#endif /* _OPENMP */
+
+#ifdef ENABLE_MPI
+    /*     gint argc_mpi; */
+    /*     gchar *argv_mpi[10]; */
+    int nprocs, rank = 0, namelen, root = 0;
+    char processor_name[MPI_MAX_PROCESSOR_NAME];
+#endif /* ENABLE_MPI */
         
-/* 
- * Initializing parameters
- */
+#ifdef ENABLE_MPI
+    /* 
+     * Initializing MPI
+     */
+    MPI_Init(&argc, &argv);
+    MPI_Comm_rank(MPI_COMM_WORLD, &rank);
+    MPI_Comm_size(MPI_COMM_WORLD, &nprocs);
+    MPI_Get_processor_name(processor_name, &namelen);
+
+/*     gpiv_warning("main:: 0 rank=%d nprocs=%d on %s", rank, nprocs, processor_name); */
+    /*     argc_mpi = argc - 4; */
+    /*     for (i = 0; i<argc_mpi; i++) { */
+    /*         gpiv_warning("main:: rank=%d argv[%d]=%s", rank, i, argv[i]); */
+    /*         argv_mpi[i] = argv[i]; */
+    /*     } */
+#endif /* ENABLE_MPI */
+
+    /* 
+     * Initializing parameters
+     */
     gpiv_piv_parameters_set (piv_par, FALSE);
     gpiv_valid_parameters_set (valid_par, FALSE);
 
-    command_args (argc, 
-                  argv, 
-                  fname_in, 
-                  piv_par,
-                  valid_par);
+#ifdef _OPENMP
+    /* 
+     * Initializing OMP
+     */
+    np = omp_get_num_procs();
+    omp_set_num_threads(np);
+    num_threads = omp_get_max_threads();
+#endif /* _OPENMP */
 
-    if (verbose) {
-        printf ("\n# %s\n# Command line options:\n", argv[0]);
-        gpiv_piv_print_parameters (stdout, piv_par);
-        gpiv_valid_print_parameters (stdout, valid_par);
-    }
+#ifdef ENABLE_MPI
+    if (rank == 0) {
+#endif /* ENABLE_MPI */
 
-/*
- * Reads piv and valid parameters from PARFILE and/or resource files 
- * if not overridden by the commandline options
- */
-    gpiv_scan_parameter (GPIV_PIVPAR_KEY, PARFILE, piv_par, verbose);
-    gpiv_scan_resourcefiles (GPIV_PIVPAR_KEY, piv_par, verbose);
-    gpiv_scan_parameter (GPIV_VALIDPAR_KEY, PARFILE, valid_par, verbose);
-    gpiv_scan_resourcefiles (GPIV_VALIDPAR_KEY, valid_par, verbose);
+        command_args (argc, 
+                      argv, 
+                      fname_in, 
+                      piv_par,
+                      valid_par);
 
-
-/*
- * Creates file names if not stdin / stdout are used
- * and save parameters
- */
-    if (use_stdin_stdout == FALSE) {
-        gchar *fname_base = g_strdup (fname_in);
-        strtok(fname_base, ".");
-        gpiv_io_make_fname (fname_base, GPIV_EXT_PAR, fname_par);
-        g_free (fname_base);
-
-        if ((fp_par_out = fopen (fname_par, "w")) == NULL) {
-            gpiv_error ("%s error: failure opening %s for input",
-                        argv[0], fname_par);
+        if (verbose) {
+            printf ("\n# %s\n# Command line options:\n", RCSID);
+            gpiv_piv_print_parameters (stdout, piv_par);
+            gpiv_valid_print_parameters (stdout, valid_par);
         }
+
+        /*
+         * Reads piv and valid parameters from PARFILE and/or resource files 
+         * if not overridden by the commandline options.
+         * Check if all parameters have been read. Else, set as libgpiv defaults
+         */
+        gpiv_scan_parameter (GPIV_PIVPAR_KEY, PARFILE, piv_par, verbose);
+        gpiv_scan_resourcefiles (GPIV_PIVPAR_KEY, piv_par, verbose);
         if ((err_msg = 
-             make_fname (fp_par_out, fname_in, fname_out, piv_par))
-            != NULL) {
-            gpiv_error ("%s: %s\n", argv[0], err_msg);
-        }
+             gpiv_piv_check_parameters_read (piv_par, NULL))
+            != NULL) gpiv_warning ("%s: %s", argv[0], err_msg);
+
+        gpiv_scan_parameter (GPIV_VALIDPAR_KEY, PARFILE, valid_par, verbose);
+        gpiv_scan_resourcefiles (GPIV_VALIDPAR_KEY, valid_par, verbose);
+        if ((err_msg = 
+             gpiv_valid_check_parameters_read (valid_par, NULL))
+            != NULL) gpiv_warning ("%s: %s", argv[0], err_msg);
+
+       /*
+         * Creates file names if not stdin / stdout are used
+         * and save parameters
+         */
+        if (use_stdin_stdout == FALSE) {
+            gchar *fname_base = g_strdup (fname_in);
+            strtok(fname_base, ".");
+            gpiv_io_make_fname (fname_base, GPIV_EXT_PAR, fname_par);
+            g_free (fname_base);
+
+            if ((fp_par_out = fopen (fname_par, "w")) == NULL) {
+                gpiv_error ("%s error: failure opening %s for input",
+                            argv[0], fname_par);
+            }
+            if ((err_msg = 
+                 make_fname (fp_par_out, fname_in, fname_out, piv_par))
+                != NULL) {
+                gpiv_error ("%s: %s\n", argv[0], err_msg);
+            }
        
 
-/*
- * Write parameters to parameterfile
- */
-        gpiv_piv_print_parameters (fp_par_out, piv_par);
-        gpiv_valid_print_parameters (fp_par_out, valid_par);
-        fclose (fp_par_out);
-    }
+            /*
+             * Write parameters to parameterfile
+             */
+            gpiv_piv_print_parameters (fp_par_out, piv_par);
+            gpiv_valid_print_parameters (fp_par_out, valid_par);
+            fclose (fp_par_out);
+        }
 
-/*
- * Check if all parameters have been read
- * Else, set as libgpiv defaults
- */
-    if ((err_msg = 
-         gpiv_piv_check_parameters_read (piv_par, NULL))
-        != NULL) gpiv_warning ("%s: %s", argv[0], err_msg);
-    
-    if ((err_msg = 
-         gpiv_valid_check_parameters_read (valid_par, NULL))
-        != NULL) gpiv_warning ("%s: %s", argv[0], err_msg);
-    
 
-/*
- * reads image
- */
+        /*
+         * reads the image
+         */
 
 #ifdef USE_MTRACE
-/*     fprintf(stderr, "Calling interrogate with mtrace()\n"); */
-    mtrace();
+        /*     fprintf(stderr, "Calling interrogate with mtrace()\n"); */
+        mtrace();
 #endif
-    if (use_stdin_stdout) {
+        if (use_stdin_stdout) {
 #ifdef DEBUG
-        g_message ("rr:: using stdin");
+            gpiv_warning ("gpiv_rr:: using stdin");
 #endif
-        if ((image = gpiv_read_image (stdin)) == NULL) {
-            gpiv_error ("%s: gpiv_fread_image_ni", argv[0]);
+            if ((image = gpiv_read_image (stdin)) == NULL) {
+                gpiv_error ("%s: gpiv_fread_image_ni", argv[0]);
+            }
+        } else {
+#ifdef DEBUG
+            gpiv_warning ("rr:: using fp, fname = %s", fname_in);
+#endif
+            if ((image = gpiv_fread_image (fname_in)) == NULL) {
+                gpiv_error ("%s: gpiv_fread_image", argv[0]);
+            }
         }
+
+#ifdef ENABLE_MPI
     } else {
-#ifdef DEBUG
-        g_message ("rr:: using fp, fname = %s", fname_in);
-#endif
-        if ((image = gpiv_fread_image (fname_in)) == NULL) {
-            gpiv_error ("%s: gpiv_fread_image", argv[0]);
-        }
+        /*
+         * allocates the memory of structures for threads of which rank != 0
+         */
+        image = alloc_image_struct();
+        piv_par = alloc_pivpar_struct();
+        valid_par = alloc_validpar_struct();
+
     }
 
 
+    if (MPI_Bcast(&verbose, 1, MPI_INT, root, MPI_COMM_WORLD) 
+        != MPI_SUCCESS) {
+        gpiv_error ("gpiv_rr: An error ocurred when calling MPI_Bcast");
+    }
+    gpiv_img_mpi_bcast_image (image, TRUE);
+    if ((err_msg = gpiv_piv_mpi_bcast_pivpar (piv_par)) != NULL) {
+        gpiv_error (err_msg);
+    }
+    gpiv_valid_mpi_bcast_validpar (valid_par);
+
+#endif /* ENABLE_MPI */
+#ifdef DEBUG
+    gpiv_warning ("gpiv_rr:: calling gpiv_piv_interrogate_img");
+#endif
+
 
 /*
- * interrogates, eventually displays, and writes PIV data
+ * Interrogating image
  */
-#ifdef DEBUG
-        g_message ("rr:: calling gpiv_piv_interrogate_img");
-#endif
     if ((piv_data = gpiv_piv_interrogate_img (image, piv_par, valid_par, verbose))
         == NULL) {
         gpiv_error ("%s: gpiv_piv_interrogate_img failed", argv[0]);
     }
-    
-
-    if (gnuplot) gpiv_piv_gnuplot (fname_in, gnuplot_scale, 
-                                   GNUPLOT_DISPLAY_COLOR, GNUPLOT_DISPLAY_SIZE,
-                                   image->header, piv_par, piv_data);
-    
 
 
-    piv_data->comment = g_strdup_printf ("# Software: %s\n", RCSID);
-    piv_data->comment = gpiv_add_datetime_to_comment (piv_data->comment);
-    piv_data->comment = g_strconcat (piv_data->comment, 
-                                     "# Data type: Particle Image Velocities\n", 
-                                     NULL);
+#ifdef ENABLE_MPI
+    if (rank == 0) {
+#endif
+        /*
+         * Displays PIV data
+         */
+        if (gnuplot) gpiv_piv_gnuplot (fname_in, gnuplot_scale, 
+                                       GNUPLOT_DISPLAY_COLOR, GNUPLOT_DISPLAY_SIZE,
+                                       image->header, piv_par, piv_data);
+
+        /*
+         * Add comments to PIV data and saving
+         */
+        piv_data->comment = g_strdup_printf ("# Software: %s\n", RCSID);
+        piv_data->comment = gpiv_add_datetime_to_comment (piv_data->comment);
+        piv_data->comment = g_strconcat (piv_data->comment, 
+                                         "# Data type: Particle Image Velocities\n", 
+                                         NULL);
 
 
-    if ((piv_par->print_piv == TRUE && use_stdin_stdout == FALSE)
-        || use_stdin_stdout == TRUE) {
-        fp_out = stdout;
-        if ((err_msg = 
-             gpiv_write_pivdata (fp_out, piv_data, FALSE))
-            != NULL) gpiv_error ("%s: %s", argv[0], err_msg);
+        if ((piv_par->print_piv == TRUE && use_stdin_stdout == FALSE)
+            || use_stdin_stdout == TRUE) {
+            fp_out = stdout;
+            if ((err_msg = 
+                 gpiv_write_pivdata (fp_out, piv_data, FALSE))
+                != NULL) gpiv_error ("%s: %s", argv[0], err_msg);
 
-    } else {
-        if ((fp_out = fopen (fname_out, "wb")) == NULL) {
-            gpiv_error ("%s: failing fopen %s", RCSID, fname_out);
-        }
-        if ((err_msg = 
-             gpiv_write_pivdata (fp_out, piv_data, FALSE))
-            != NULL) gpiv_error ("%s: %s", argv[0], err_msg);
-        fclose (fp_out);
+        } else {
+            if ((fp_out = fopen (fname_out, "wb")) == NULL) {
+                gpiv_error ("%s: failing fopen %s", argv[0], fname_out);
+            }
+            if ((err_msg = 
+                 gpiv_write_pivdata (fp_out, piv_data, FALSE))
+                != NULL) gpiv_error ("%s: %s", argv[0], err_msg);
+            fclose (fp_out);
         
+        }
+#ifdef ENABLE_MPI
     }
-    
-    
-/*
- * Free memory of images and data
- */
+#endif
+
+    /*
+     * Free memory of images and data
+     */
     gpiv_free_pivdata (piv_data);
     if (image->frame1 != NULL && image->frame2 != NULL) {
         gpiv_free_img (image);
@@ -728,5 +831,13 @@ main (int argc,
 #ifdef USE_MTRACE
     muntrace();
 #endif
-    exit (0);
+
+/* #endif */ /* __DISABLE */
+#ifdef ENABLE_MPI
+#ifdef DEBUG
+        gpiv_warning("main:: rank=%d: Calling MPI_Finalize()", rank);
+#endif /* DEBUG */
+        MPI_Finalize();
+#endif /* ENABLE+MPI */
+        exit (0);
 }
