@@ -23,6 +23,12 @@
 
    RCS version control
    $Log: imgproc.c,v $
+   Revision 2.10  2008-09-25 13:08:34  gerber
+   Changed RCID to argv[0] in (error) messages
+
+   Revision 2.9  2008-04-28 12:09:30  gerber
+   hdf-formatted files are now with .hdf extension (previously: .gpi)
+
    Revision 2.8  2007-11-23 16:18:55  gerber
    release 0.5.0: Kafka
 
@@ -89,7 +95,7 @@ filename:         full image filename. Overrides stdin and stdout.  \n\
 #define HELP  "\
 Image processing program for PIV images."
 
-#define RCSID "$Id: imgproc.c,v 2.8 2007-11-23 16:18:55 gerber Exp $"
+#define RCSID "$Id: imgproc.c,v 2.10 2008-09-25 13:08:34 gerber Exp $"
 
 /*
  * Global variables
@@ -128,7 +134,7 @@ command_args (int argc,
 		exit(0);
 		break;
 	    case 'h':
-		printf("\n%s", RCSID);
+		printf("\n%s", argv[0]);
 		printf("\n%s", HELP);
 		printf("\n%s", USAGE);
 		exit(0);
@@ -194,7 +200,7 @@ command_args (int argc,
  */
 	    case '-':
 		if (strcmp("-help", *argv) == 0) {
-                    printf("\n%s", RCSID);
+                    printf("\n%s", argv[0]);
                     printf("\n%s", HELP);
                     printf("\n%s", USAGE);
                     exit(0);
@@ -223,13 +229,13 @@ command_args (int argc,
                     argc_next = 1;
 
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
 
 	    default:
-		gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		break;
 	    }
 	}
@@ -242,7 +248,7 @@ command_args (int argc,
         use_stdin_stdout = TRUE;
         verbose = FALSE;
     } else {
-	gpiv_error("%s: unknown argument: %s", RCSID, *argv);
+	gpiv_error("%s: unknown argument: %s", argv[0], *argv);
     }
 
 }
