@@ -27,6 +27,15 @@ BUGS:
 
 RCS version control
    $Log: t-avg-img.c,v $
+   Revision 2.11  2008-10-09 14:45:01  gerber
+   paralellized with OMP and MPI
+
+   Revision 2.10  2008-09-25 13:08:34  gerber
+   Changed RCID to argv[0] in (error) messages
+
+   Revision 2.9  2008-04-28 12:09:30  gerber
+   hdf-formatted files are now with .hdf extension (previously: .gpi)
+
    Revision 2.8  2007-11-23 16:18:55  gerber
    release 0.5.0: Kafka
 
@@ -96,7 +105,7 @@ keys: \n\
 Calculates time-averaged intensities from a series of images for each pixel. \n\
 Images should be numbered at the start or at the end of its name"
 
-#define RCSID "$Id: t-avg-img.c,v 2.8 2007-11-23 16:18:55 gerber Exp $"
+#define RCSID "$Id: t-avg-img.c,v 2.11 2008-10-09 14:45:01 gerber Exp $"
 
 /*---------- Global variables ---------------------------------------------*/
 gboolean fname__set = FALSE;
@@ -136,7 +145,7 @@ command_args (int argc, char *argv[],
 		exit(0);
 		break;
 	    case 'h':
-		printf("\n%s", RCSID);
+		printf("\n%s", argv[0]);
 		printf("\n%s", HELP);
 		printf("\n%s", USAGE);
 		exit(0);
@@ -202,14 +211,14 @@ command_args (int argc, char *argv[],
 		break;
 
 	    default:
-		gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		break;
 	    }
 	}
     }
 
     if (argc != 0) {
-	gpiv_error("%s: unknown argument: %s", RCSID, *argv);
+	gpiv_error("%s: unknown argument: %s", argv[0], *argv);
     }
 
 
@@ -497,7 +506,7 @@ main (int argc,
 	    gpiv_error ("%s: failure opening %s for input",
                        argv[0], fname_parameter);
 	}
-	fprintf (fp_par_dat, "\n\n# %s\n# Command line options:\n", RCSID);
+	fprintf (fp_par_dat, "\n\n# %s\n# Command line options:\n", argv[0]);
 	gpiv_genpar_print_parameters (fp_par_dat, gen_par);
 	gpiv_imgproc_print_parameters (fp_par_dat, image_proc_par);
 
