@@ -39,13 +39,13 @@ keys: \n\
 -p | --print:          print parameters to stdout \n\
 -v | --version:        version number \n\
 -V | --verbose:        version number \n\
-filename:              input file, hdf formatted (including .gpi extension) \n\
+filename:              input file, hdf formatted (including .hdf extension) \n\
 "
 
 #define HELP  "\
 hdf2piv - converts hdf5 PIV-data to ASCII data"
 
-#define RCSID "$Id: hdf2piv.c,v 1.11 2007-11-23 16:18:55 gerber Exp $"
+#define RCSID "$Id: hdf2piv.c,v 1.13 2008-09-25 13:08:34 gerber Exp $"
 
 gboolean print_par = FALSE, verbose = FALSE, exclude_data = FALSE;
 
@@ -85,7 +85,7 @@ command_args(gint argc,
                 exclude_data = TRUE;
                 break;
             case 'h':
-                printf("%s\n", RCSID); 
+                printf("%s\n", argv[0]); 
                 printf("%s\n",HELP);
                 printf("%s\n",USAGE);
                 exit(0);
@@ -99,7 +99,7 @@ command_args(gint argc,
  */
 	    case '-':
 		if (strcmp("-help", *argv) == 0) {
-                    printf("\n%s", RCSID);
+                    printf("\n%s", argv[0]);
                     printf("\n%s", HELP);
                     printf("\n%s", USAGE);
                     exit(0);
@@ -111,7 +111,7 @@ command_args(gint argc,
                 } else if (strcmp("-verbose", *argv) == 0) {
                     verbose = TRUE;
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
@@ -125,7 +125,7 @@ command_args(gint argc,
     if (argc == 1) {
         strcpy (fname, argv[argc - 1]);
     } else {
-        gpiv_error ("%s: %s", RCSID, USAGE);
+        gpiv_error ("%s: %s", argv[0], USAGE);
     }
 
 }
@@ -233,12 +233,12 @@ main(int argc,
  * image data
  */
     if ((image = gpiv_fread_hdf5_image (fname_in)) == NULL) {
-        gpiv_error ("%s: %s", RCSID, err_msg);
+        gpiv_error ("%s: %s", argv[0], err_msg);
     }
 
     if ((fp_out = fopen (fname_out_img, "wb")) == NULL) {
         gpiv_error("%s error: failure opening %s for output",
-                   RCSID, fname_out_img);
+                   argv[0], fname_out_img);
     }
     gpiv_write_png_image (fp_out, image, TRUE);
     fclose(fp_out);
@@ -248,17 +248,17 @@ main(int argc,
  */ 
     if (exclude_data == FALSE) {
         if ((piv_data = gpiv_fread_hdf5_pivdata (fname_in, "PIV" )) == NULL) {
-            gpiv_error ("%s: failing gpiv_fread_hdf5_pivdata", RCSID);
+            gpiv_error ("%s: failing gpiv_fread_hdf5_pivdata", argv[0]);
         }
 
         if ((fp_out = fopen (fname_out_piv, "w")) == NULL) {
             gpiv_error("%s error: failure opening %s for output",
-                       RCSID, fname_out_piv);
+                       argv[0], fname_out_piv);
         }
 
         if ((err_msg = gpiv_write_pivdata (fp_out, piv_data, TRUE)) 
             != NULL) {
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
         fclose(fp_out);
 
@@ -267,17 +267,17 @@ main(int argc,
  */
         if ((sc_data = gpiv_fread_hdf5_scdata (fname_in, "VORTICITY" )) 
             == NULL) {
-            gpiv_error ("%s: failing gpiv_fread_hdf5_scdata", RCSID);
+            gpiv_error ("%s: failing gpiv_fread_hdf5_scdata", argv[0]);
         }
 
         if ((fp_out = fopen (fname_out_vor, "w")) == NULL) {
             gpiv_error("%s error: failure opening %s for output",
-                       RCSID, fname_out_vor);
+                       argv[0], fname_out_vor);
         }
         
         if ((err_msg = gpiv_write_scdata (fp_out, sc_data, TRUE)) 
             != NULL) {
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
         fclose(fp_out);
          
@@ -286,17 +286,17 @@ main(int argc,
  */
         if ((sc_data = gpiv_fread_hdf5_scdata (fname_in, "NORMAL STRAIN" )) 
             == NULL) {
-            gpiv_error ("%s: failing gpiv_fread_hdf5_scdata", RCSID);
+            gpiv_error ("%s: failing gpiv_fread_hdf5_scdata", argv[0]);
         }
 
         if ((fp_out = fopen (fname_out_nstrain, "w")) == NULL) {
             gpiv_error("%s error: failure opening %s for output",
-                       RCSID, fname_out_vor);
+                       argv[0], fname_out_vor);
         }
         
         if ((err_msg = gpiv_write_scdata (fp_out, sc_data, TRUE)) 
             != NULL) {
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
         fclose(fp_out);
 
@@ -305,17 +305,17 @@ main(int argc,
  */
         if ((sc_data = gpiv_fread_hdf5_scdata (fname_in, "SHEAR STRAIN" )) 
             == NULL) {
-            gpiv_error ("%s: failing gpiv_fread_hdf5_scdata", RCSID);
+            gpiv_error ("%s: failing gpiv_fread_hdf5_scdata", argv[0]);
         }
 
         if ((fp_out = fopen (fname_out_sstrain, "w")) == NULL) {
             gpiv_error("%s error: failure opening %s for output",
-                       RCSID, fname_out_vor);
+                       argv[0], fname_out_vor);
         }
         
         if ((err_msg = gpiv_write_scdata (fp_out, sc_data, TRUE)) 
             != NULL) {
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
         fclose(fp_out);
 
@@ -325,25 +325,25 @@ main(int argc,
          if ((piv_par =
               gpiv_piv_fread_hdf5_parameters (fname_in))
              == NULL)  {
-             gpiv_error ("%s: failing gpiv_piv_fread_hdf5_parameters", RCSID);
+             gpiv_error ("%s: failing gpiv_piv_fread_hdf5_parameters", argv[0]);
          }
 
          if ((valid_par =
               gpiv_valid_fread_hdf5_parameters (fname_in))
              == NULL)  {
-             gpiv_error ("%s: failing gpiv_valid_fread_hdf5_parameters", RCSID);
+             gpiv_error ("%s: failing gpiv_valid_fread_hdf5_parameters", argv[0]);
          }
 
          if ((post_par =
               gpiv_post_fread_hdf5_parameters(fname_in))
              == NULL) {
-             gpiv_error ("%s: failing gpiv_post_fread_hdf5_parameters", RCSID);
+             gpiv_error ("%s: failing gpiv_post_fread_hdf5_parameters", argv[0]);
          }
 
 
          if ((fp_out = fopen (fname_out_par, "w")) == NULL) {
              gpiv_error("%s error: failure opening %s for output",
-                        RCSID, fname_out_par);
+                        argv[0], fname_out_par);
          }
          gpiv_img_print_parameters (fp_out, image->header);
          gpiv_piv_print_parameters (fp_out, piv_par);
