@@ -46,7 +46,7 @@ filename:              inpit PIV data file. \n\
 #define HELP  "\
 piv2gnuplt - converts PIV data gnuplot data"
 
-#define RCSID "$Id: piv2gnuplt.c,v 1.10 2007-11-23 16:18:55 gerber Exp $"
+#define RCSID "$Id: piv2gnuplt.c,v 1.12 2008-09-25 13:08:34 gerber Exp $"
 #define GNUPLOT_DISPLAY_SIZE 500
 #define GNUPLOT_DISPLAY_COLOR "LightBlue"
 
@@ -93,7 +93,7 @@ command_args(int argc,
 		    argc_next = 1;
 		    --argc;
                 } else {
-                    gpiv_error("%s: %s", RCSID, USAGE);
+                    gpiv_error("%s: %s", argv[0], USAGE);
                 }
                 annot__set = TRUE;
                 break;
@@ -102,7 +102,7 @@ command_args(int argc,
                 exit(0);
                 break;
              case 'h':
-                printf("%s\n", RCSID); 
+                printf("%s\n", argv[0]); 
                 printf("%s\n",HELP);
                 printf("%s\n",USAGE);
                 exit(0);
@@ -125,7 +125,7 @@ command_args(int argc,
  */
 	    case '-':
 		if (strcmp("-help", *argv) == 0) {
-                    printf("\n%s", RCSID);
+                    printf("\n%s", argv[0]);
                     printf("\n%s", HELP);
                     printf("\n%s", USAGE);
                     exit(0);
@@ -135,7 +135,7 @@ command_args(int argc,
                     printf("%s\n", RCSID);
                     exit(0);
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
@@ -148,7 +148,7 @@ command_args(int argc,
     }
 
      if(argc != 1) { 
-	  gpiv_error("%s: %s", RCSID, USAGE);
+	  gpiv_error("%s: %s", argv[0], USAGE);
      }
      strcpy(fname, argv[0]); 
 
@@ -229,7 +229,7 @@ main(int argc,
     gpiv_scan_parameter ("", PARFILE, image_par, print_par);
     if ((err_msg =
          gpiv_scan_resourcefiles(GPIV_IMGPAR_KEY, image_par, print_par))
-        != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);    
+        != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);    
 
 /*
  * Reads piv parameters from PARFILE and/or resource files 
@@ -238,24 +238,24 @@ main(int argc,
     gpiv_scan_parameter (GPIV_PIVPAR_KEY, PARFILE, piv_par, print_par);
     if ((err_msg =
          gpiv_scan_resourcefiles (GPIV_PIVPAR_KEY, piv_par, print_par))
-        != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+        != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
 /*
  * Check if all parameters have been read
  */
 /*     gpiv_img_check_header_read(GPIV_IMAGE_PAR_KEY); */
     if ((err_msg =
          gpiv_piv_check_parameters_read (piv_par, NULL))
-        != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+        != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
 /*
  * As piv_data.nx and piv_data.ny are not known, the input data file will 
  * first be read
  */
     if ((fp = fopen (fname_in, "r")) == NULL) {
-        gpiv_error ("%s: failing opening %s", RCSID, fname_in);
+        gpiv_error ("%s: failing opening %s", argv[0], fname_in);
     }
 
     if ((piv_data = gpiv_read_pivdata (fp)) == NULL) {
-        gpiv_error ("%s: failing gpiv_fread_pivdata", RCSID);
+        gpiv_error ("%s: failing gpiv_fread_pivdata", argv[0]);
     }
     fclose (fp);
 /* 
