@@ -46,7 +46,7 @@ piv2grid - converts PIV data to grid data for generating contour plots \n\
 plotmtv \n\
 "
 
-#define RCSID "$Id: piv2grid.c,v 1.8 2007-11-23 16:18:55 gerber Exp $"
+#define RCSID "$Id: piv2grid.c,v 1.9 2008-09-25 13:08:34 gerber Exp $"
 
 enum DataType {
   DT_DX = 0,
@@ -87,7 +87,7 @@ command_args(int argc,
                 exit(0);
                 break;
             case 'h':
-                printf("%s\n", RCSID); 
+                printf("%s\n", argv[0]); 
                 printf("%s\n",HELP);
                 printf("%s\n",USAGE);
                 exit(0);
@@ -116,7 +116,7 @@ command_args(int argc,
  */
 	    case '-':
 		if (strcmp("-help", *argv) == 0) {
-                    printf("\n%s", RCSID);
+                    printf("\n%s", argv[0]);
                     printf("\n%s", HELP);
                     printf("\n%s", USAGE);
                     exit(0);
@@ -126,7 +126,7 @@ command_args(int argc,
                     printf("%s\n", RCSID);
                     exit(0);
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
@@ -140,7 +140,7 @@ command_args(int argc,
         
     }
      if(argc != 1) { 
-	  gpiv_error("%s: %s", RCSID, USAGE);
+	  gpiv_error("%s: %s", argv[0], USAGE);
      }
      strcpy(fname, argv[0]); 
 
@@ -200,18 +200,18 @@ main(int argc,
  * Reading PIV data
  */
     if ((fp = fopen (fname_piv, "r")) == NULL) {
-        gpiv_error ("%s: failing opening %s", RCSID, fname_piv);
+        gpiv_error ("%s: failing opening %s", argv[0], fname_piv);
     }
 
     if ((piv_data = gpiv_read_pivdata(fp)) != NULL) {
-        gpiv_error ("%s: %s", RCSID, err_msg);
+        gpiv_error ("%s: %s", argv[0], err_msg);
     }
 
 /*
  * copying PIV data to SCALAR data
  */
     if ((sc_data = gpiv_alloc_scdata (piv_data->nx, piv_data->ny)) == NULL) {
-        gpiv_error ("%s: failing gpiv_alloc_scdata", RCSID);
+        gpiv_error ("%s: failing gpiv_alloc_scdata", argv[0]);
     }
 
     for (i = 0; i < sc_data->ny; i++) {
@@ -235,11 +235,11 @@ main(int argc,
  * Saving SCALAR data
  */
     if ((fp = fopen (fname_out, "w")) == NULL) {
-        gpiv_error ("%s: failing opening %s", RCSID, fname_out);
+        gpiv_error ("%s: failing opening %s", argv[0], fname_out);
     }
 
     if ((err_msg = gpiv_write_sc_mtvgriddata (fp, sc_data, TRUE))
-        != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+        != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
 
 
 
