@@ -46,7 +46,7 @@ filename:              input PIV datafile, including .piv extension \n\
 #define HELP  "\
 piv2hdf - converts ASCII PIV-data and derived scalars to hdf5 formatted data"
 
-#define RCSID "$Id: piv2hdf.c,v 1.11 2007-11-23 16:18:55 gerber Exp $"
+#define RCSID "$Id: piv2hdf.c,v 1.12 2008-09-25 13:08:34 gerber Exp $"
 
 gboolean print_par = FALSE,  verbose = FALSE, exclude_data = FALSE, 
     include_image = FALSE;
@@ -86,7 +86,7 @@ command_args(gint argc,
                 exclude_data = TRUE;
                 break;
             case 'h':
-                printf("%s\n", RCSID); 
+                printf("%s\n", argv[0]); 
                 printf("%s\n",HELP);
                 printf("%s\n",USAGE);
                 exit(0);
@@ -103,7 +103,7 @@ command_args(gint argc,
  */
 	    case '-':
 		if (strcmp("-help", *argv) == 0) {
-                    printf("\n%s", RCSID);
+                    printf("\n%s", argv[0]);
                     printf("\n%s", HELP);
                     printf("\n%s", USAGE);
                     exit(0);
@@ -115,7 +115,7 @@ command_args(gint argc,
                 } else if (strcmp("-verbose", *argv) == 0) {
                     verbose = TRUE;
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
@@ -127,7 +127,7 @@ command_args(gint argc,
      }
 
      if(argc != 1) { 
-	  gpiv_error("%s: %s", RCSID, USAGE);
+	  gpiv_error("%s: %s", argv[0], USAGE);
      }
      strcpy(fname, argv[0]); 
 
@@ -260,20 +260,20 @@ main(int argc,
 #ifdef USE_RESOURCES
     if ((err_msg =
          gpiv_scan_resourcefiles (GPIV_PIVPAR_KEY, piv_par, print_par))
-        != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+        != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
     if ((err_msg =
          gpiv_scan_resourcefiles (GPIV_VALIDPAR_KEY, valid_par, print_par))
-        != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+        != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
     if ((err_msg =
          gpiv_scan_resourcefiles (GPIV_POSTPAR_KEY, post_par, print_par))
-        != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+        != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
 #endif /* USE_RESOURCES */
 
 /* 
  * writing to output int hdf5
  */
     if ((err_msg = gpiv_fcreate_hdf5 (fname_out)) != NULL)  {
-        gpiv_error ("%s: %s", RCSID, err_msg);
+        gpiv_error ("%s: %s", argv[0], err_msg);
     }
 
 
@@ -284,14 +284,14 @@ main(int argc,
         if ((fp = fopen(fname_img, "r")) != NULL) {
             if ((image = gpiv_read_png_image (fp)) == NULL) {
                 fclose(fp);
-                gpiv_error ("%s: faling gpiv_read_png_image", RCSID);
+                gpiv_error ("%s: faling gpiv_read_png_image", argv[0]);
             }
             fclose(fp);
             fp = NULL;
 
             if ((err_msg = gpiv_fwrite_hdf5_image (fname_out, image, TRUE)) 
                 != NULL) {
-                gpiv_error ("%s: %s", RCSID, err_msg);
+                gpiv_error ("%s: %s", argv[0], err_msg);
             }
         }
     }
@@ -304,27 +304,27 @@ main(int argc,
          if ((fp = fopen (fname_piv, "r")) != NULL) {
              if ((piv_data = gpiv_read_pivdata (fp)) == NULL) {
                 fclose(fp);
-                gpiv_error ("%s: faling gpiv_read_pivdata", RCSID);
+                gpiv_error ("%s: faling gpiv_read_pivdata", argv[0]);
             }
             fclose(fp);
             fp = NULL;
 
             if ((err_msg = gpiv_fwrite_hdf5_pivdata (fname_out, piv_data,  "PIV", 
                                                      TRUE))
-                != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+                != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
             
 
 
              if (piv_par != NULL) {
                  if ((err_msg = 
                       gpiv_piv_fwrite_hdf5_parameters (fname_out, piv_par))
-                     != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+                     != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
              }
 
              if (valid_par != NULL) {
                  if ((err_msg = 
                       gpiv_valid_fwrite_hdf5_parameters (fname_out, valid_par))
-                     != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+                     != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
              }
 
          }
@@ -335,21 +335,21 @@ main(int argc,
          if ((fp = fopen (fname_vor, "r")) != NULL) {
              if ((sc_data = gpiv_read_scdata (fp)) == NULL) {
                  fclose(fp);
-                 gpiv_error ("%s: faling gpiv_read_scdata", RCSID);
+                 gpiv_error ("%s: faling gpiv_read_scdata", argv[0]);
              }
              fclose(fp);
              fp = NULL;
 
              if ((err_msg = gpiv_fwrite_hdf5_scdata (fname_out, sc_data, 
                                                      "VORTICITY", TRUE))
-                 != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+                 != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
 
 
              if (post_par != NULL && stored__post_par == FALSE) {
                  stored__post_par = TRUE;
                  if ((err_msg = 
                       gpiv_post_fwrite_hdf5_parameters (fname_out, post_par))
-                     != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+                     != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
              }
          }
 
@@ -360,7 +360,7 @@ main(int argc,
 
              if ((sc_data = gpiv_read_scdata (fp)) == NULL) {
                  fclose(fp);
-                 gpiv_error ("%s: faling gpiv_read_scdata", RCSID);
+                 gpiv_error ("%s: faling gpiv_read_scdata", argv[0]);
              }
              fclose(fp);
              fp = NULL;
@@ -368,13 +368,13 @@ main(int argc,
              if ((err_msg =
                   gpiv_fwrite_hdf5_scdata(fname_out, sc_data, 
                                           "SHEAR_STRAIN", TRUE))
-                != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+                != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
 
              if (post_par != NULL && stored__post_par == FALSE) {
                  stored__post_par = TRUE;
                  if ((err_msg =
                       gpiv_post_fwrite_hdf5_parameters (fname_out, post_par))
-                     != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+                     != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
              }
          }
          
@@ -384,7 +384,7 @@ main(int argc,
          if((fp=fopen(fname_nstrain, "r")) != NULL) {
              if ((sc_data = gpiv_read_scdata (fp)) == NULL) {
                  fclose(fp);
-                 gpiv_error ("%s: faling gpiv_read_scdata", RCSID);
+                 gpiv_error ("%s: faling gpiv_read_scdata", argv[0]);
              }
              fclose(fp);
              fp = NULL;
@@ -393,13 +393,13 @@ main(int argc,
              if ((err_msg =
                   gpiv_fwrite_hdf5_scdata(fname_out, sc_data, 
                                      "NORMAL_STRAIN", TRUE))
-                 != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+                 != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
 
              if (post_par != NULL && stored__post_par == FALSE) {
                  stored__post_par = TRUE;
                  if ((err_msg =
                       gpiv_post_fwrite_hdf5_parameters (fname_out, post_par))
-                     != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+                     != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
              }
          }
      }
