@@ -49,7 +49,7 @@ filename_ta            File name of time-averaged (local means) PIV data set \n\
 #define HELP  "\
 suta - subtracts time-avaraged velocities (local mean) from the PIV estimators"
 
-#define RCSID "$Id: suta.c,v 1.5 2007-11-23 16:18:55 gerber Exp $"
+#define RCSID "$Id: suta.c,v 1.6 2008-09-25 13:08:34 gerber Exp $"
 
 gboolean print_par = FALSE;
 
@@ -83,7 +83,7 @@ command_args(int argc,
                 exit(0);
                 break;
             case 'h':
-                printf("%s\n", RCSID); 
+                printf("%s\n", argv[0]); 
                 printf("%s\n",HELP);
                 printf("%s\n",USAGE);
                 exit(0);
@@ -97,7 +97,7 @@ command_args(int argc,
  */
 	    case '-':
 		if (strcmp("-help", *argv) == 0) {
-                    printf("\n%s", RCSID);
+                    printf("\n%s", argv[0]);
                     printf("\n%s", HELP);
                     printf("\n%s", USAGE);
                     exit(0);
@@ -107,7 +107,7 @@ command_args(int argc,
                     printf("%s\n", RCSID);
                     exit(0);
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
@@ -119,7 +119,7 @@ command_args(int argc,
     }
 
     if(argc != 2) { 
-        gpiv_error("%s: %s", RCSID, USAGE);
+        gpiv_error("%s: %s", argv[0], USAGE);
     }
 
     strcpy(fname_mean, argv[0]);
@@ -180,22 +180,22 @@ main(int argc,
 
 
     if ((fp = fopen (fname_in, "r")) == NULL) {
-        gpiv_error ("%s: failing opening %s", RCSID, fname_in);
+        gpiv_error ("%s: failing opening %s", argv[0], fname_in);
     }
 
     if ((in_data = gpiv_read_pivdata (fp)) == NULL) {
-        gpiv_error ("%s: failing gpiv_read_pivdata", RCSID, err_msg);
+        gpiv_error ("%s: failing gpiv_read_pivdata", argv[0], err_msg);
     }
     fclose (fp);
 
 
 
     if ((fp = fopen (fname_mean, "r")) == NULL) {
-        gpiv_error ("%s: failing opening %s", RCSID, fname_mean);
+        gpiv_error ("%s: failing opening %s", argv[0], fname_mean);
     }
 
     if ((mean_data = gpiv_read_pivdata (fp)) == NULL) {
-        gpiv_error ("%s: gpiv_read_pivdata", RCSID, err_msg);
+        gpiv_error ("%s: gpiv_read_pivdata", argv[0], err_msg);
     }
     fclose (fp);
 
@@ -221,11 +221,11 @@ main(int argc,
     
 
     if ((fp = fopen (fname_out, "w")) == NULL) {
-        gpiv_error ("%s: failing opening %s", RCSID, fname_out);
+        gpiv_error ("%s: failing opening %s", argv[0], fname_out);
     }
 
     if ((err_msg = gpiv_write_pivdata(fp, out_data, TRUE)) != NULL) {
-        gpiv_error ("%s: %s", RCSID, err_msg);
+        gpiv_error ("%s: %s", argv[0], err_msg);
     }
     fclose (fp);
     
