@@ -52,7 +52,7 @@ file_basename          File basename of a numbered series of PIV data sets \n\
 #define HELP  "\
 t-corr - calculates the Eulerian correlation from a series of PIV data sets"
 
-#define RCSID "$Id: t-corr.c,v 1.5 2007-11-23 16:18:55 gerber Exp $"
+#define RCSID "$Id: t-corr.c,v 1.6 2008-09-25 13:08:34 gerber Exp $"
 
 gboolean print_par = FALSE;
 typedef struct _TimeCorrPar TimeCorrPar;
@@ -99,7 +99,7 @@ command_args(int argc,
                 exit(0);
                 break;
             case 'h':
-                printf("%s\n", RCSID); 
+                printf("%s\n", argv[0]); 
                 printf("%s\n",HELP);
                 printf("%s\n",USAGE);
                 exit(0);
@@ -148,7 +148,7 @@ command_args(int argc,
  */
 	    case '-':
 		if (strcmp("-help", *argv) == 0) {
-                    printf("\n%s", RCSID);
+                    printf("\n%s", argv[0]);
                     printf("\n%s", HELP);
                     printf("\n%s", USAGE);
                     exit(0);
@@ -178,7 +178,7 @@ command_args(int argc,
                     argc_next = 1;
                     --argc;
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
@@ -190,7 +190,7 @@ command_args(int argc,
     }
 
     if(argc != 1) { 
-        gpiv_error("%s: %s", RCSID, USAGE);
+        gpiv_error("%s: %s", argv[0], USAGE);
     }
 
     strcpy(fname, argv[0]);
@@ -291,7 +291,7 @@ main(int argc,
     if (time_corr_par->last_file < time_corr_par->first_file
         || (time_corr_par->last_file - time_corr_par->first_file) > MAX_PIVSETS) {
         gpiv_error("%s: last_file smaller than first_file or total number of data sets exceeds MAX_PIVSETS=%d",
-                   RCSID, MAX_PIVSETS);
+                   argv[0], MAX_PIVSETS);
     }
 
 
@@ -319,11 +319,11 @@ main(int argc,
         if (i == 0) {
 
             if ((fp = fopen (fname_in, "r")) == NULL) {
-                gpiv_error ("%s: failing opening %s", RCSID, fname_in);
+                gpiv_error ("%s: failing opening %s", argv[0], fname_in);
             }
 
             if ((in_data = gpiv_read_pivdata (fp)) != NULL)  {
-                gpiv_error ("%s: %s", RCSID, err_msg);
+                gpiv_error ("%s: %s", argv[0], err_msg);
             }
             fclose (fp);
 
