@@ -44,7 +44,7 @@ filename:              image file name \n\
 #define HELP  "\
 gpiv_aint calculates mean image intensity at each interrogation area"
 
-#define RCSID "$Id: aint.c,v 2.2 2007-11-23 16:18:55 gerber Exp $"
+#define RCSID "$Id: aint.c,v 2.5 2008-09-25 13:08:34 gerber Exp $"
 /*
  * Extension of filename means: "Interrogation Area Intensity"
  */
@@ -527,7 +527,7 @@ command_args (int argc,
                 break;
 
             case 'h':
-                printf ("%s\n", RCSID); 
+                printf ("%s\n", argv[0]); 
                 printf ("%s\n", HELP);
                 printf ("%s\n", USAGE);
                 exit (0);
@@ -550,7 +550,7 @@ command_args (int argc,
  */
 	    case '-':
 		if (strcmp ("-help", *argv) == 0) {
-                    printf ("\n%s", RCSID);
+                    printf ("\n%s", argv[0]);
                     printf ("\n%s", HELP);
                     printf ("\n%s", USAGE);
                     exit (0);
@@ -564,7 +564,7 @@ command_args (int argc,
                     printf ("%s\n", RCSID);
                     exit (0);
                 } else {
-		    gpiv_error ("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error ("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
@@ -581,7 +581,7 @@ command_args (int argc,
     if (argc == 1) {
         strcpy (fname, *argv); 
     } else {
-        gpiv_error ("%s: %s", RCSID, USAGE);
+        gpiv_error ("%s: %s", argv[0], USAGE);
     }
 
 }
@@ -669,7 +669,7 @@ main (int argc,
         gpiv_error ("\n%s: failure opening %s for input",
                     argv[0], fname_par);
     }
-    fprintf (fp_par, "\n\n# %s\n# Command line options:\n", argv[0]); 
+    fprintf (fp_par, "\n\n# %s\n# Command line options:\n", RCSID); 
 
 /*
  * Reading parametes from PARFILE and (system) resources (and writing to data 
@@ -745,7 +745,7 @@ main (int argc,
  *  And writing to output
  */
     if ((fp = fopen (fname_out, "wb")) == NULL) {
-        gpiv_error ("failing opening %s", fname_out);
+        gpiv_error ("%s: failing opening %s", argv[0], fname_out);
     }
     if ((err_msg =
          gpiv_write_scdata (fp, sc_out_data, TRUE))
