@@ -75,7 +75,7 @@ keys: \n\
 manipulates order and positions of PIV data, flips in horizontal \n\
 or vertical direction and rotates over 90 or 180 degrees"
 
-#define RCSID "$Id: manipiv.c,v 2.10 2007-11-23 16:18:55 gerber Exp $"
+#define RCSID "$Id: manipiv.c,v 2.13 2008-09-25 13:08:34 gerber Exp $"
 
 /*
  * Global variables 
@@ -123,7 +123,7 @@ command_args(int argc,
 		exit(0);
 		break;
 	    case 'h':
-		printf("\n%s", RCSID);
+		printf("\n%s", argv[0]);
 		printf("\n%s", HELP);
 		printf("\n%s", USAGE);
 #ifdef DEBUG
@@ -213,7 +213,7 @@ command_args(int argc,
                     --argc;
                     argc_next = 1;
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
                 break;
@@ -223,7 +223,7 @@ command_args(int argc,
  */
 	    case '-':
 		if (strcmp("-help", *argv) == 0) {
-                    printf("\n%s", RCSID);
+                    printf("\n%s", argv[0]);
                     printf("\n%s", HELP);
                     printf("\n%s", USAGE);
                     exit(0);
@@ -252,13 +252,13 @@ command_args(int argc,
                     --argc;
                     argc_next = 1;
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
 
 	    default:
-		gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		break;
 	    }
 	}
@@ -274,7 +274,7 @@ command_args(int argc,
         use_stdin_stdout = TRUE;
         verbose = FALSE;
     } else {
-	gpiv_error("%s: unknown argument: %s", RCSID, *argv);
+	gpiv_error("%s: unknown argument: %s", argv[0], *argv);
     }
 
 
@@ -381,16 +381,16 @@ main(int argc,
              make_fname (fname_in_piv, fname_parameter, fname_out))
             != NULL) 
             gpiv_error("%s: Failure calling make_fname",
-		    RCSID);
+		    argv[0]);
 
 /*
  * Prints command line parameters to par-file
  */
 	if ((fp_par_dat = fopen(fname_parameter, "a")) == NULL) {
 	    gpiv_error("%s: failure opening %s for input",
-		    RCSID, fname_parameter);
+		    argv[0], fname_parameter);
 	}
-	fprintf(fp_par_dat, "\n\n# %s\n# Command line options:\n", RCSID);
+	fprintf(fp_par_dat, "\n\n# %s\n# Command line options:\n", argv[0]);
 	gpiv_post_print_parameters (fp_par_dat, piv_post_par);
 
 
@@ -400,7 +400,7 @@ main(int argc,
         gpiv_scan_parameter (GPIV_POSTPAR_KEY, PARFILE, piv_post_par, verbose);
         if ((err_msg =
              gpiv_scan_resourcefiles (GPIV_POSTPAR_KEY, piv_post_par, verbose))
-            != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+            != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
         gpiv_post_print_parameters (fp_par_dat, piv_post_par);
 	fclose(fp_par_dat);
 
@@ -409,7 +409,7 @@ main(int argc,
         gpiv_scan_parameter (GPIV_POSTPAR_KEY, PARFILE, piv_post_par, verbose);
         if ((err_msg =
              gpiv_scan_resourcefiles (GPIV_POSTPAR_KEY, piv_post_par, verbose))
-            != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+            != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
     }
 
     gpiv_post_check_parameters_read (piv_post_par, NULL);
@@ -423,20 +423,21 @@ main(int argc,
         fp = stdin;
     } else {
         if ((fp = fopen (fname_in_piv, "r")) == NULL) { 
-            gpiv_error ("Failure opening for input"); 
+            gpiv_error ("%s: Failure opening %s for input", 
+                        argv[0], fname_in_piv); 
         }
     }
 
     if (piv_post_par->operator_manipiv == GPIV_FAST_Y) {
         if ((piv_data = gpiv_read_pivdata_fastx (fp)) == NULL) {
             err_msg = "GPIV_POST_MANIPIV: Failure calling read_pivdata_fast_x";
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
         
     } else {
         if ((piv_data = gpiv_read_pivdata (fp)) == NULL) {
             err_msg = "GPIV_POST_MANIPIV: Failure calling gpiv_read_pivdata";
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
         
     }
@@ -446,7 +447,7 @@ main(int argc,
  * Here the library function call of the post-processing.
  */
     if ((err_msg = gpiv_post_manipiv (piv_data, piv_post_par)) != NULL) {
-        gpiv_error ("%s: ", RCSID, err_msg);
+        gpiv_error ("%s: ", argv[0], err_msg);
     }
 
 /*
@@ -461,13 +462,14 @@ main(int argc,
         fp = stdout;
     } else {
         if ((fp = fopen (fname_out, "w")) == NULL) { 
-            gpiv_error ("Failure opening for output"); 
+            gpiv_error ("%s: Failure opening %s for output", 
+                        argv[0], fname_out); 
         }
     }
 
     if ((err_msg = gpiv_write_pivdata (fp, piv_data, TRUE)) != NULL) {
         fclose (fp);
-        gpiv_error ("%s: %s", RCSID, err_msg);
+        gpiv_error ("%s: %s", argv[0], err_msg);
     }
     if (use_stdin_stdout == FALSE) fclose (fp);
 
