@@ -62,7 +62,7 @@ keys: \n\
 #define HELP  "\
 s-avg reports spatial global mean velocity and rms error of a PIV data stream"
 
-#define RCSID "$Id: s-avg.c,v 2.11 2007-11-23 16:18:56 gerber Exp $"
+#define RCSID "$Id: s-avg.c,v 2.14 2008-09-25 13:08:35 gerber Exp $"
 
 /*
  * Global variables 
@@ -111,7 +111,7 @@ command_args(int argc, char *argv[],
                 exit(0);
 
             case 'h':
-          printf("%s\n", RCSID); 
+          printf("%s\n", argv[0]); 
           printf("%s\n",HELP);
           printf("%s\n",USAGE);
 #ifdef DEBUG
@@ -169,7 +169,7 @@ command_args(int argc, char *argv[],
  */
 	    case '-':
 		if (strcmp("-help", *argv) == 0) {
-                    printf("\n%s", RCSID);
+                    printf("\n%s", argv[0]);
                     printf("\n%s", HELP);
                     printf("\n%s", USAGE);
                     exit(0);
@@ -179,7 +179,7 @@ command_args(int argc, char *argv[],
                     printf("%s\n", RCSID);
                     exit(0);
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
@@ -208,7 +208,7 @@ command_args(int argc, char *argv[],
 #ifdef DEBUG
         printf ("\n%s", USAGE_DEBUG);
 #endif
-        gpiv_error("%s: %s", RCSID, USAGE);
+        gpiv_error("%s: %s", argv[0], USAGE);
     }
 }
 
@@ -283,7 +283,7 @@ main (int argc,
     gpiv_scan_parameter (GPIV_POSTPAR_KEY, PARFILE, piv_post_par, verbose);
     if ((err_msg =
          gpiv_scan_resourcefiles (GPIV_POSTPAR_KEY, piv_post_par, verbose))
-        != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+        != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
     gpiv_post_check_parameters_read (piv_post_par, NULL);
 
     if (use_stdin_stdout == FALSE) {
@@ -296,10 +296,10 @@ main (int argc,
  * Prints parameters to par-file 
  */
         if ((fp_par_dat = fopen (fname_parameter, "a")) == NULL) {
-            gpiv_error ("%s: failure opening %s for input\n", RCSID,
+            gpiv_error ("%s: failure opening %s for input\n", argv[0],
                         fname_parameter);
         }
-        fprintf (fp_par_dat, "# %s\n# Post parameters:\n", RCSID);
+        fprintf (fp_par_dat, "# %s\n# Post parameters:\n", argv[0]);
         gpiv_post_print_parameters (fp_par_dat, piv_post_par);
 	fclose (fp_par_dat);
     }
@@ -314,13 +314,14 @@ main (int argc,
     if (use_stdin_stdout == TRUE) {
         fp = stdin;
     } else {
-        if ((fp = fopen (fname_out, "rb")) == NULL) {
-            gpiv_error ("%s: failure opening fp for writing", RCSID);
+        if ((fp = fopen (fname_in, "rb")) == NULL) {
+            gpiv_error ("%s: failure opening %s for reading", 
+                        argv[0], fname_in);
         }
     }
 
     if ((piv_data = gpiv_read_pivdata (fp)) == NULL) {
-        gpiv_error ("%s: %s", RCSID, err_msg);
+        gpiv_error ("%s: %s", argv[0], err_msg);
     }
     if (use_stdin_stdout == FALSE) fclose (fp);
 
@@ -335,7 +336,7 @@ main (int argc,
 
 
     if ((err_msg = gpiv_post_savg (piv_data, piv_post_par)) != NULL) {
-        gpiv_error ("%s: ", RCSID, err_msg);
+        gpiv_error ("%s: ", argv[0], err_msg);
     }
 
 /*
@@ -350,13 +351,14 @@ main (int argc,
         if (use_stdin_stdout == TRUE) {
             fp = stdout;
         } else {
-            if ((fp = fopen (fname_out, "w")) == NULL) {
-                gpiv_error ("%s: failure opening fp for writing", RCSID);
+            if ((fp = fopen (fname_out, "wb")) == NULL) {
+                gpiv_error ("%s: failure opening %s for writing", 
+                            argv[0], fname_out);
             }
         }
 
         if ((err_msg = gpiv_write_pivdata (fp, piv_data, FALSE)) != NULL) {
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
         if (use_stdin_stdout == FALSE) fclose (fp);
 
@@ -378,9 +380,9 @@ main (int argc,
                     piv_data->max_dy);
 
         } else {
-            if ((fp = fopen (fname_out,"w")) ==NULL) { 
+            if ((fp = fopen (fname_out,"wb")) == NULL) { 
                 gpiv_error ("\n%s: Failure opening %s for output\n",
-                            RCSID, fname_out); 
+                            argv[0], fname_out); 
             }
 
             fprintf (fp, "# Software: %s\n", RCSID);
