@@ -61,7 +61,7 @@ keys: \n\
 #define HELP  "\
 scale applies spatial and time scaling to PIV data"
 
-#define RCSID "$Id: scale.c,v 2.11 2007-11-23 16:18:56 gerber Exp $"
+#define RCSID "$Id: scale.c,v 2.14 2008-09-25 13:08:35 gerber Exp $"
 
 /*
  * Global variables
@@ -112,7 +112,7 @@ command_args(int argc,
 		    break;
 
 	       case 'h':
-		    printf("%s\n", RCSID); 
+		    printf("%s\n", argv[0]); 
 		    printf("%s\n",HELP);
 		    printf("%s\n",USAGE);
 #ifdef DEBUG
@@ -197,7 +197,7 @@ command_args(int argc,
  */
 	    case '-':
 		if (strcmp("-help", *argv) == 0) {
-                    printf("\n%s", RCSID);
+                    printf("\n%s", argv[0]);
                     printf("\n%s", HELP);
                     printf("\n%s", USAGE);
                     exit(0);
@@ -207,7 +207,7 @@ command_args(int argc,
                     printf("%s\n", RCSID);
                     exit(0);
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
@@ -236,7 +236,7 @@ command_args(int argc,
 #ifdef DEBUG
 	  printf ("\n%s", USAGE_DEBUG);
 #endif
-	  gpiv_error("%s: %s", RCSID, USAGE);
+	  gpiv_error("%s: %s", argv[0], USAGE);
      }
 
 
@@ -319,7 +319,7 @@ main (int argc,
     gpiv_scan_parameter(GPIV_POSTPAR_KEY, PARFILE, post_par, verbose);
     if ((err_msg =
          gpiv_scan_resourcefiles(GPIV_POSTPAR_KEY, post_par, verbose))
-        != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+        != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
     
     if (use_stdin_stdout == FALSE) {
 /*
@@ -328,7 +328,7 @@ main (int argc,
         if ((err_msg = 
              make_fname (fname_in, fname_header, fname_parameter, fname_out)) 
             != NULL) {
-            gpiv_error("%s: Failure calling make_fname", RCSID);
+            gpiv_error("%s: Failure calling make_fname", argv[0]);
         } 
 
 /*
@@ -336,9 +336,9 @@ main (int argc,
  */
         if ((fp_par_dat = fopen (fname_parameter, "a")) == NULL) {
             gpiv_error("\n%s: failure opening %s for input",
-                       RCSID, fname_parameter);
+                       argv[0], fname_parameter);
         }
-        fprintf(fp_par_dat, "\n\n# %s\n# Command line options:\n", RCSID); 
+        fprintf(fp_par_dat, "\n\n# %s\n# Command line options:\n", argv[0]); 
         gpiv_img_print_parameters(fp_par_dat, image_par);
 
 /*
@@ -351,7 +351,7 @@ main (int argc,
         if ((err_msg =
              gpiv_scan_resourcefiles(GPIV_IMGPAR_KEY, image_par, 
                                      verbose))
-            != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+            != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
         gpiv_img_print_parameters (fp_par_dat, image_par);
         gpiv_post_print_parameters (fp_par_dat, post_par);
 
@@ -364,8 +364,7 @@ main (int argc,
         if ((err_msg =
              gpiv_scan_resourcefiles (GPIV_IMGPAR_KEY, image_par, 
                                      verbose))
-            != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
-
+            != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
     }
 
 
@@ -375,13 +374,14 @@ main (int argc,
     if (use_stdin_stdout == TRUE) {
         fp = stdin;
     } else {
-        if ((fp = fopen (fname_out, "rb")) == NULL) {
-            gpiv_error ("%s: failure opening fp for writing", RCSID);
+        if ((fp = fopen (fname_in, "rb")) == NULL) {
+            gpiv_error ("%s: failure opening %s for reading", 
+                        argv[0], fname_in);
         }
     }
 
     if ((piv_data = gpiv_read_pivdata (fp)) == NULL) {
-        gpiv_error ("%s: %s", RCSID, err_msg);
+        gpiv_error ("%s: %s", argv[0], err_msg);
     }
     if (use_stdin_stdout == FALSE) fclose (fp);
 
@@ -393,21 +393,21 @@ main (int argc,
 
     if (post_par->scale_type == GPIV_SCALE) {
         if ((err_msg = gpiv_post_scale (piv_data, image_par)) != NULL) {
-            gpiv_error("%s: Failure calling gpiv_post_scale", RCSID);
+            gpiv_error("%s: Failure calling gpiv_post_scale", argv[0]);
         }
         var_scale = TRUE;
     } else if (post_par->scale_type == GPIV_SCALE_INV) {
         if ((err_msg = gpiv_post_inverse_scale (piv_data, image_par)) != NULL) {
-            gpiv_error("%s: Failure calling gpiv_post_inverse_scale", RCSID);
+            gpiv_error("%s: Failure calling gpiv_post_inverse_scale", argv[0]);
         }
         var_scale = TRUE;
     } else {
-        gpiv_error("scale:: used unexisting image_par.s_scale__set");
+        gpiv_error("scale: used unexisting image_par.s_scale__set");
     }
 
 /*
  * Adding comment to the data
- *  And writing data to output
+ * And writing data to output
  */
     g_free (piv_data->comment);
     piv_data->comment = g_strdup_printf ("# Software: %s\n", RCSID);
@@ -416,13 +416,14 @@ main (int argc,
     if (use_stdin_stdout == TRUE) {
         fp = stdout;
     } else {
-        if ((fp = fopen (fname_out, "r")) == NULL) { 
-            gpiv_error ("Failure opening for output"); 
+        if ((fp = fopen (fname_out, "wb")) == NULL) { 
+            gpiv_error ("%s: Failure opening %s for output", 
+                        argv[0], fname_out); 
         }
     }
 
     if ((err_msg = gpiv_write_pivdata (fp, piv_data, TRUE)) != NULL) {
-        gpiv_error ("%s: %s", RCSID, err_msg);
+        gpiv_error ("%s: %s", argv[0], err_msg);
     }
     if (use_stdin_stdout == FALSE) fclose (fp);
 
