@@ -79,7 +79,7 @@ keys: \n\
 vorstra calculates the differential quantities vorticity, shear strain and \n\
 normal strain from PIV data."
 
-#define RCSID "$Id: vorstra.c,v 2.12 2007-12-19 08:47:49 gerber Exp $"
+#define RCSID "$Id: vorstra.c,v 2.16 2008-10-09 14:45:01 gerber Exp $"
 
 
 gboolean use_stdin_stdout = FALSE;
@@ -146,7 +146,7 @@ command_args(int argc,
 	      gnuplot__set = TRUE;
 	      break;
 	    case 'h':
-		printf("\n%s", RCSID);
+		printf("\n%s", argv[0]);
 		printf("\n%s", HELP);
 		printf("\n%s\n", USAGE);
 		exit(0);
@@ -192,7 +192,7 @@ command_args(int argc,
  */
 	    case '-':
 		if (strcmp("-help", *argv) == 0) {
-                    printf("\n%s", RCSID);
+                    printf("\n%s", argv[0]);
                     printf("\n%s", HELP);
                     printf("\n%s", USAGE);
                     exit(0);
@@ -211,14 +211,14 @@ command_args(int argc,
                     argc_next = 1;
 
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
 
 	    default:
 		gpiv_error("\n%s error : unknown option: %s\n",
-			RCSID, *argv);
+			argv[0], *argv);
 		break;
 	    }
 	}
@@ -234,7 +234,7 @@ command_args(int argc,
         use_stdin_stdout = TRUE;
         verbose = FALSE;
     } else {
-	gpiv_error("\n%s error: unknown argument: %s\n", RCSID, *argv);
+	gpiv_error("\n%s error: unknown argument: %s\n", argv[0], *argv);
     }
 
 }
@@ -351,8 +351,8 @@ main(int argc,
  */
 	if ((fp_par_dat = fopen(fname_parameter, "a")) == NULL)
 	     gpiv_error("\n%s: failure opening %s for input",
-			RCSID, fname_parameter);
-      fprintf(fp_par_dat, "# %s\n# Command line options:\n", RCSID);
+			argv[0], fname_parameter);
+      fprintf(fp_par_dat, "# %s\n# Command line options:\n", argv[0]);
       gpiv_post_print_parameters (fp_par_dat, piv_post_par);
 
 /*
@@ -361,7 +361,7 @@ main(int argc,
         gpiv_scan_parameter (GPIV_POSTPAR_KEY, PARFILE, piv_post_par, verbose);
         if ((err_msg =
              gpiv_scan_resourcefiles (GPIV_POSTPAR_KEY, piv_post_par, verbose))
-            != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+            != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
         gpiv_post_print_parameters (fp_par_dat, piv_post_par);
 	fclose (fp_par_dat);
 
@@ -370,7 +370,7 @@ main(int argc,
         gpiv_scan_parameter (GPIV_POSTPAR_KEY, PARFILE, piv_post_par, verbose);
         if ((err_msg =
              gpiv_scan_resourcefiles (GPIV_POSTPAR_KEY, piv_post_par, verbose))
-            != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+            != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
     }
 
     gpiv_post_check_parameters_read (piv_post_par, NULL);
@@ -385,19 +385,19 @@ main(int argc,
              && piv_post_par->diff_type != 2
 	     && piv_post_par->diff_type != 3)
 	      gpiv_error("%s error: no value differential differentiator type",
-			 RCSID);
+			 argv[0]);
     }
 
     if (use_stdin_stdout == TRUE && gnuplot == 1) {
         gpiv_error ("%s: filename has to be used in combination with 'gnuplot'\n",
-                    RCSID);
+                    argv[0]);
     }
 
     if ((piv_post_par->operator_vorstra == GPIV_S_STRAIN 
 	 || piv_post_par->operator_vorstra == GPIV_N_STRAIN)
 	&& piv_post_par->diff_type == GPIV_CIRCULATION) {
         gpiv_error ("\n%s error: strain can not be calculated by circulation method",
-                    RCSID);
+                    argv[0]);
     }
 
 
@@ -407,13 +407,13 @@ main(int argc,
     if (use_stdin_stdout == TRUE) {
         fp = stdin;
     } else {
-        if ((fp = fopen (fname_in, "r")) == NULL) { 
-            gpiv_error ("Failure opening for input"); 
+        if ((fp = fopen (fname_in, "rb")) == NULL) { 
+            gpiv_error ("%s: Failure opening %s for input", argv[0], fname_in); 
         }
     }
 
     if ((in_data = gpiv_read_pivdata (fp)) == NULL) {
-        gpiv_error ("%s: %s", RCSID, err_msg);
+        gpiv_error ("%s: %s", argv[0], err_msg);
     }
     if (use_stdin_stdout == FALSE) fclose (fp);
 
@@ -423,7 +423,7 @@ main(int argc,
  */
 
     if ((out_data = gpiv_post_vorstra (in_data, piv_post_par)) == NULL) {
-        gpiv_error ("%s: %s", RCSID, err_msg);
+        gpiv_error ("%s: %s", argv[0], err_msg);
     }
 
 /*
@@ -451,18 +451,18 @@ main(int argc,
     if (use_stdin_stdout == TRUE) {
         fp = stdout;
     } else {
-        if ((fp = fopen (fname_out, "w")) == NULL) { 
-            gpiv_error ("Failure opening for output"); 
+        if ((fp = fopen (fname_out, "wb")) == NULL) { 
+            gpiv_error ("%s: Failure opening %s for output", argv[0], fname_out);
         }
     }
 
     if (gnuplot == 1) {
         if ((err_msg = gpiv_write_sc_griddata (fp, out_data, TRUE)) != NULL) {
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
     } else {
         if ((err_msg = gpiv_write_scdata (fp, out_data, TRUE)) != NULL) {
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
     }
     if (use_stdin_stdout == FALSE) fclose (fp);
