@@ -66,7 +66,7 @@ filename:              input PIV file. Substitutes stdin and stdout \n\
 errvec searches the erroneous vectors in a PIV data set and eventually \n\
 substitutes them with new values."
 
-#define RCSID "$Id: errvec.c,v 2.12 2007-11-23 16:18:56 gerber Exp $"
+#define RCSID "$Id: errvec.c,v 2.16 2008-10-09 14:45:01 gerber Exp $"
 
 /*
  * Global variables for the parameters
@@ -130,7 +130,7 @@ command_args(int argc,
 		break;
 
 	    case 'h':
-		printf("%s\n", RCSID);
+		printf("%s\n", argv[0]);
 		printf("%s\n", HELP);
 		printf("%s\n", USAGE);
 #ifdef DEBUG
@@ -223,7 +223,7 @@ command_args(int argc,
  */
 	    case '-':
 		if (strcmp("-help", *argv) == 0) {
-                    printf("\n%s", RCSID);
+                    printf("\n%s", argv[0]);
                     printf("\n%s", HELP);
                     printf("\n%s", USAGE);
                     exit(0);
@@ -247,7 +247,7 @@ command_args(int argc,
                     itype__set = TRUE;
 
                 } else {
-		    gpiv_error("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error("%s: unknown option: %s", argv[0], *argv);
 		}
 		argc_next = 1;
 		break;
@@ -272,7 +272,7 @@ command_args(int argc,
 #ifdef DEBUG
 	printf("\n%s", USAGE_DEBUG);
 #endif
-        gpiv_error("\n%s: unknown argument: %s: %s", RCSID, *argv, USAGE);
+        gpiv_error("\n%s: unknown argument: %s: %s", argv[0], *argv, USAGE);
     }
 
     return 0;
@@ -378,7 +378,7 @@ main (int argc,
         if ((err_msg = 
              make_fname (fname_in_piv, fname_img, fname_parameter, fname_out))
             != NULL) {
-	    gpiv_error ("%s: Failure calling make_fname", RCSID);
+	    gpiv_error ("%s: Failure calling make_fname", argv[0]);
 	}
 
 
@@ -387,9 +387,9 @@ main (int argc,
  */
 	if ((fp_par_dat = fopen (fname_parameter, "a")) == NULL) {
 	    gpiv_error ("%s: failure opening %s for input",
-		    RCSID, fname_parameter);
+		    argv[0], fname_parameter);
 	}
-	fprintf (fp_par_dat, "\n\n # %s\n# Command line options:\n", RCSID);
+	fprintf (fp_par_dat, "\n\n # %s\n# Command line options:\n", argv[0]);
 	gpiv_valid_print_parameters (fp_par_dat, valid_par);
     g_message (":: 2");
 
@@ -403,7 +403,7 @@ main (int argc,
         if ((err_msg =
              gpiv_scan_resourcefiles (GPIV_VALIDPAR_KEY, valid_par, 
                                      verbose))
-            != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+            != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
 
 
         if (res_stats == TRUE
@@ -415,7 +415,7 @@ main (int argc,
                                 verbose);
             if ((err_msg =
                  gpiv_scan_resourcefiles (GPIV_PIVPAR_KEY, piv_par, verbose))
-                != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+                != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
             gpiv_piv_print_parameters (fp_par_dat, piv_par);
         }
 	fclose (fp_par_dat);
@@ -430,7 +430,7 @@ main (int argc,
         if ((err_msg =
              gpiv_scan_resourcefiles (GPIV_VALIDPAR_KEY, valid_par, 
                                      verbose))
-            != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+            != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
 
         if (res_stats == TRUE
             || auto_thresh == TRUE) {
@@ -439,7 +439,7 @@ main (int argc,
         if ((err_msg =
              gpiv_scan_resourcefiles (GPIV_PIVPAR_KEY, piv_par, 
                                      verbose))
-            != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+            != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
         }
    }
 
@@ -456,12 +456,12 @@ main (int argc,
     if (use_stdin_stdout == TRUE 
         && valid_par->subst_type == GPIV_VALID_SUBSTYPE__COR_PEAK) {
 	gpiv_error ("%s: -f \"filename\" has to be used in combination with "
-		   "'peak'", RCSID);
+		   "'peak'", argv[0]);
     }
 
     if (use_stdin_stdout == TRUE && gnuplot == TRUE) {
 	gpiv_error ("%s: -f \"filename\" has to be used in combination with "
-		   "'gnuplot'", RCSID);
+		   "'gnuplot'", argv[0]);
     }
 
 
@@ -476,17 +476,17 @@ main (int argc,
         }
 
         if ((fp = fopen (fname_in_piv, "rb")) == NULL) {
-            gpiv_error ("%s: failing fopen %s", RCSID, fname_in_piv);
+            gpiv_error ("%s: failing fopen %s", argv[0], fname_in_piv);
         }
 
         if ((in_data = gpiv_read_pivdata (fp)) == NULL)  {
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
         fclose (fp);
 
     } else {
         if ((in_data = gpiv_read_pivdata (NULL)) == NULL) {
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
     }
 
@@ -504,7 +504,7 @@ main (int argc,
     if (auto_thresh == TRUE
         || res_stats == TRUE) {
         if ((err_msg = gpiv_valid_residu (in_data, valid_par, TRUE)) != NULL) {
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
         out_data = gpiv_cp_pivdata (in_data);
 
@@ -528,7 +528,7 @@ main (int argc,
  */
     if ((err_msg = 
          gpiv_valid_errvec (in_data, image, piv_par, valid_par, FALSE))
-        != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+        != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
     }
     out_data = gpiv_cp_pivdata (in_data);
 /*
@@ -542,23 +542,23 @@ main (int argc,
 	if (use_stdin_stdout == FALSE) {
             if ((fp_par_dat = fopen (fname_parameter, "a")) == NULL) {
                 gpiv_error ("%s: failure opening %s for input",
-                           RCSID, fname_parameter);
+                           argv[0], fname_parameter);
             }
             gpiv_valid_print_parameters (fp_par_dat, valid_par);
             fclose (fp_par_dat);
 
 
             if ((fp = fopen (fname_out, "wb")) == NULL) {
-                gpiv_error ("%s: failing fopen %s", RCSID, fname_out);
+                gpiv_error ("%s: failing fopen %s", argv[0], fname_out);
             }
             if ((err_msg =
                  gpiv_write_pivdata (fp, out_data, TRUE))
-                != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+                != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
             fclose (fp);
 	} else {
             if ((err_msg =
                  gpiv_write_pivdata (NULL, out_data, TRUE))
-                != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+                != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
 	}
 
 /*
@@ -605,7 +605,7 @@ main (int argc,
 	    gpiv_print_cumhisto_eqdatbin (NULL, klass, FALSE);
 	} else {
             if ((fp = fopen (fname_out, "wb")) == NULL) {
-                gpiv_error ("%s: failure fopen", RCSID);
+                gpiv_error ("%s: failure fopen %s", argv[0], fname_out);
             }
 	    gpiv_print_cumhisto_eqdatbin (fp, klass, FALSE);
 	}
