@@ -50,7 +50,7 @@ keys: \n\
 filename:              input PIV file. Substitutes stdin and stdout \n\
 "
 
-#define RCSID "$Id: peaklck.c,v 2.11 2007-12-19 08:47:49 gerber Exp $"
+#define RCSID "$Id: peaklck.c,v 2.14 2008-09-25 13:08:35 gerber Exp $"
 
 
 /*
@@ -98,7 +98,7 @@ void command_args (int argc, char *argv[],
 		break;
 
 	    case 'h':
-		printf ("%s\n", RCSID);
+		printf ("%s\n", argv[0]);
 		printf ("%s\n", HELP);
 		printf ("%s\n", USAGE);
 		exit (1);
@@ -116,7 +116,7 @@ void command_args (int argc, char *argv[],
  */
 	    case '-':
 		if (strcmp ("-help", *argv) == 0) {
-                    printf ("\n%s", RCSID);
+                    printf ("\n%s", argv[0]);
                     printf ("\n%s", HELP);
                     printf ("\n%s", USAGE);
                     exit (0);
@@ -129,14 +129,14 @@ void command_args (int argc, char *argv[],
                     exit (0);
 
                 } else {
-		    gpiv_error ("%s: unknown option: %s", RCSID, *argv);
+		    gpiv_error ("%s: unknown option: %s", argv[0], *argv);
 		}
 
 		argc_next = 1;
 		break;
 
 	    default:
-		gpiv_error ("%s: unknown option: %s", RCSID, *argv);
+		gpiv_error ("%s: unknown option: %s", argv[0], *argv);
 		break;
 	    }
 	}
@@ -151,7 +151,7 @@ void command_args (int argc, char *argv[],
         use_stdin_stdout = TRUE;
         print_par = FALSE;
     } else {
- 	gpiv_error ("%s: unknown argument: %s", RCSID, *argv);
+ 	gpiv_error ("%s: unknown argument: %s", argv[0], *argv);
     }
 
 }
@@ -238,7 +238,7 @@ int main (int argc, char *argv[])
 
     command_args (argc, argv, fname_in, valid_par, &nbins, &nbins__set);
     if (print_par) {
-        printf ("# %s\n# Command line options:\n", RCSID);
+        printf ("# %s\n# Command line options:\n", argv[0]);
         gpiv_valid_print_parameters (NULL, valid_par);
     }
 
@@ -252,7 +252,7 @@ int main (int argc, char *argv[])
     if ((err_msg =
          gpiv_scan_resourcefiles (GPIV_VALIDPAR_KEY, valid_par, 
                                   print_par))
-        != NULL)  gpiv_error ("%s: %s", RCSID, err_msg);
+        != NULL)  gpiv_error ("%s: %s", argv[0], err_msg);
 
 
     if (use_stdin_stdout == FALSE) {
@@ -270,8 +270,8 @@ int main (int argc, char *argv[])
  * Prints command line parameters to stdout and par-file
  */
 	if ((fp_par_dat = fopen (fname_parameter, "a")) == NULL) {
-	    gpiv_error ("%s: failure opening %s for input", 
-                        RCSID, fname_parameter);
+	    gpiv_error ("%s: failure fopen %s", 
+                        argv[0], fname_parameter);
 	}
 	fprintf (fp_par_dat, "\n\n# %s\n# Command line options:\n", RCSID);
 	gpiv_valid_print_parameters (fp_par_dat, valid_par);
@@ -292,16 +292,16 @@ int main (int argc, char *argv[])
 
     if (use_stdin_stdout == FALSE) {
         if ((fp = fopen (fname_in, "rb")) == NULL) {
-            gpiv_error ("%s: failing fopen %s", RCSID, fname_in);
+            gpiv_error ("%s: failure fopen %s", argv[0], fname_in);
         }
         if ((in_data = gpiv_read_pivdata (fp)) == NULL)  {
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
         fclose (fp);
 
     } else {
         if ((in_data = gpiv_read_pivdata (NULL)) == NULL)  {
-            gpiv_error ("%s: %s", RCSID, err_msg);
+            gpiv_error ("%s: %s", argv[0], err_msg);
         }
     }
 
@@ -312,13 +312,13 @@ int main (int argc, char *argv[])
         klass = gpiv_post_uvhisto (in_data, nbins, operator);	  
     } else {
         if ((klass = gpiv_valid_peaklck (in_data, nbins)) == NULL) {
-            gpiv_error ("%s: gpiv_valid_peaklck__ni failed", RCSID);
+            gpiv_error ("%s: gpiv_valid_peaklck__ni failed", argv[0]);
         }
     }
 
     if (use_stdin_stdout == FALSE) {
         if ((fp = fopen (fname_out, "wb")) == NULL) {
-            gpiv_error ("failure opening %s for output", fname_out);
+            gpiv_error ("%s: failure fopen %s", argv[0], fname_out);
         }
         gpiv_print_histo (fp, klass, FALSE);
         fclose (fp);
@@ -342,7 +342,7 @@ int main (int argc, char *argv[])
         if ((err_msg = 
              gpiv_histo_gnuplot (fname_out, title, GNUPLOT_DISPLAY_COLOR, 
                                  GNUPLOT_DISPLAY_SIZE))
-            != NULL) gpiv_error ("%s: %s", RCSID, err_msg);   
+            != NULL) gpiv_error ("%s: %s", argv[0], err_msg);   
     }
 
 
